==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/th-TH/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'เกี่ยวกับสถานที่',
    'about_locations'           => 'สถานที่ถูกใช้เพื่อติดตามข้อมูลตำแหน่งสำหรับผู้ใช้เนื้อหาและรายการอื่น ๆ',
    'assets_rtd'                => 'สินทรัพย์', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Assets Assigned',
    'id'                        => 'ID',
    'city'                      => 'เขต/อำเภอ',
    'state'                     => 'เมือง/รัฐ',
    'country'                   => 'ประเทศ',
    'create'                    => 'สร้างสถานที่',
    'update'                    => 'อัพเดทสถานที่',
    'print_assigned'            => 'พิมพ์ งานที่มอบหมาย',
    'print_all_assigned'        => 'พิมพ์ งานที่มอบหมาย ทั้งหมด',
    'name'                      => 'ชื่อสถานที่',
    'address'                   => 'ที่อยู่',
    'address2'                   => 'Address Line 2',
    'zip'                       => 'รหัสไปรษณีย์',
    'locations'                 => 'สถานที่',
    'parent'                    => 'หมวดแม่',
    'currency'                  => 'สกุลเงินตามสถานที่',
    'ldap_ou'                   => 'LDU Search OU',
    'user_name'                 => 'ชื่อผู้ใช้',
    'department'                => 'แผนก',
    'location'                  => 'ที่ตั้ง',
    'asset_tag'                 => 'รหัสทรัพย์สิน',
    'asset_name'                => 'ชื่อ',
    'asset_category'            => 'หมวดหมู่',
    'asset_manufacturer'        => 'ผู้ผลิต',
    'asset_model'               => 'รุ่น',
    'asset_serial'              => 'หมายเลขผลิตภัณฑ์',
    'asset_location'            => 'ที่ตั้ง',
    'asset_checked_out'         => 'เช็คเอาท์',
    'asset_expected_checkin'    => 'วันที่เช็คอินที่คาดหวังไว้',
    'date'                      => 'วันเดือนปี',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'ลงชื่อ (ผู้ตรวจรายการทรัพทย์สิน)',
    'signed_by_finance_auditor' => 'ลงชื่อ (ผู้ตรวจการเงิน)',
    'signed_by_location_manager' => 'ลงชื่อ (หัวหน้าจุด)',
    'signed_by'                 => 'ลงชื่อออก',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/th-TH/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'เกี่ยวกับสถานที่',
    'about_locations'           => 'สถานที่ถูกใช้เพื่อติดตามข้อมูลตำแหน่งสำหรับผู้ใช้เนื้อหาและรายการอื่น ๆ',
    'assets_rtd'                => 'สินทรัพย์', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Assets Assigned',
    'id'                        => 'ID',
    'city'                      => 'เขต/อำเภอ',
    'state'                     => 'เมือง/รัฐ',
    'country'                   => 'ประเทศ',
    'create'                    => 'สร้างสถานที่',
    'update'                    => 'อัพเดทสถานที่',
    'print_assigned'            => 'พิมพ์ งานที่มอบหมาย',
    'print_all_assigned'        => 'พิมพ์ งานที่มอบหมาย ทั้งหมด',
    'name'                      => 'ชื่อสถานที่',
    'address'                   => 'ที่อยู่',
    'address2'                   => 'ที่อยู่บรรทัดที่ 2',
    'zip'                       => 'รหัสไปรษณีย์',
    'locations'                 => 'สถานที่',
    'parent'                    => 'หมวดแม่',
    'currency'                  => 'สกุลเงินตามสถานที่',
    'ldap_ou'                   => 'LDU Search OU',
    'user_name'                 => 'ชื่อผู้ใช้',
    'department'                => 'แผนก',
    'location'                  => 'ที่ตั้ง',
    'asset_tag'                 => 'รหัสทรัพย์สิน',
    'asset_name'                => 'ชื่อ',
    'asset_category'            => 'หมวดหมู่',
    'asset_manufacturer'        => 'ผู้ผลิต',
    'asset_model'               => 'รุ่น',
    'asset_serial'              => 'หมายเลขผลิตภัณฑ์',
    'asset_location'            => 'ที่ตั้ง',
    'asset_checked_out'         => 'เช็คเอาท์',
    'asset_expected_checkin'    => 'วันที่เช็คอินที่คาดหวังไว้',
    'date'                      => 'วันเดือนปี',
    'phone'                     => 'หมายเลขโทรศัพท์',
    'signed_by_asset_auditor'   => 'ลงชื่อ (ผู้ตรวจรายการทรัพทย์สิน)',
    'signed_by_finance_auditor' => 'ลงชื่อ (ผู้ตรวจการเงิน)',
    'signed_by_location_manager' => 'ลงชื่อ (หัวหน้าจุด)',
    'signed_by'                 => 'ลงชื่อออก',
];
